@echo off
setlocal

REM 检查参数是否提供
if "%1"=="" (
    echo 请提供GitHub项目的地址
    exit /b 1
)

REM 克隆GitHub项目
git clone %1
if errorlevel 1 (
    echo 克隆失败，请检查项目地址
    exit /b 1
)

REM 获取项目目录名
for %%i in (%1) do set project_name=%%~ni

REM 切换到项目目录
cd %project_name%

REM 创建虚拟环境
python -m venv venv
if errorlevel 1 (
    echo 虚拟环境创建失败
    exit /b 1
)

REM 激活虚拟环境
call .\venv\Scripts\activate
if errorlevel 1 (
    echo 虚拟环境激活失败
    exit /b 1
)

REM 升级pip
python.exe -m pip install --upgrade pip
if errorlevel 1 (
    echo pip升级失败
    exit /b 1
)

REM 安装torch及其依赖
pip install torch==2.2.2+cu121 torchvision==0.17.2+cu121 torchaudio==2.2.2+cu121 --index-url https://download.pytorch.org/whl/cu121
if errorlevel 1 (
    echo 安装torch失败
    exit /b 1
)

REM 检查当前目录是否存在 requirements.txt 文件
if exist requirements.txt (
    REM 安装其他依赖
    pip install -r requirements.txt
    if errorlevel 1 (
        echo 安装其他依赖失败
        exit /b 1
    )
) 

if exist setup.py (
    REM 如果存在 setup.py 文件，则执行 pip install -e .
    pip install -e .
    if errorlevel 1 (
        echo 安装依赖失败
        exit /b 1
    )
)

echo 完成

endlocal
